Index: mojo/system/channel.h |
diff --git a/mojo/system/channel.h b/mojo/system/channel.h |
index 4af6daa8a0acca9a613558d9c17b3a397e766db5..fe876beaf364d5a3e2e27f7840ef4495aa9e4da6 100644 |
--- a/mojo/system/channel.h |
+++ b/mojo/system/channel.h |
@@ -59,11 +59,9 @@ class MOJO_SYSTEM_IMPL_EXPORT Channel |
// This must be called on the creation thread before any other methods are |
// called, and before references to this object are given to any other |
- // threads. |handle| should be a handle to a (platform-appropriate) |
- // bidirectional communication channel (e.g., a socket on POSIX, a named pipe |
- // on Windows). Returns true on success. On failure, no other methods should |
- // be called (including |Shutdown()|). |
- bool Init(embedder::ScopedPlatformHandle handle); |
+ // threads. |raw_channel| should be uninitialized. Returns true on success. On |
+ // failure, no other methods should be called (including |Shutdown()|). |
+ bool Init(scoped_ptr<RawChannel> raw_channel); |
// This must be called on the creation thread before destruction (which can |
// happen on any thread). |